summaryrefslogtreecommitdiffstats
path: root/etc
diff options
context:
space:
mode:
authorjkh <jkh@FreeBSD.org>1994-06-28 07:28:28 +0000
committerjkh <jkh@FreeBSD.org>1994-06-28 07:28:28 +0000
commit6d707c8ea56487e4ce028df8199faa685f9e2782 (patch)
treef6aa20c9ac316cb596e6964a10b1a4604ac4775c /etc
parent04b81774933d81b0ed49702dab0336823cedff14 (diff)
downloadFreeBSD-src-6d707c8ea56487e4ce028df8199faa685f9e2782.zip
FreeBSD-src-6d707c8ea56487e4ce028df8199faa685f9e2782.tar.gz
Add --unlink flag to all tar commands, but each for different reasons.
1. Add to secr and bindists to possibly save the occasional fool who doesn't RTFM and uses the wrong command to extract this (or even someone who's legitimately using this to extract on top of a bindist somewhere *else*). 2. Do the right thing with any symlinks in the src tree. Right now, we're free of the buggers, but just in case.
Diffstat (limited to 'etc')
-rwxr-xr-xetc/etc.i386/EXTRACT_bin.sh2
-rwxr-xr-xetc/etc.i386/EXTRACT_secr.sh4
-rwxr-xr-xetc/etc.i386/EXTRACT_src.sh30
3 files changed, 18 insertions, 18 deletions
diff --git a/etc/etc.i386/EXTRACT_bin.sh b/etc/etc.i386/EXTRACT_bin.sh
index e35e0a2..d682174 100755
--- a/etc/etc.i386/EXTRACT_bin.sh
+++ b/etc/etc.i386/EXTRACT_bin.sh
@@ -14,5 +14,5 @@ if [ X"${EXTRACT_TARGET}" = X"" ]; then
fi
cd $SOURCEDIR
-cat bin_tgz.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
+cat bin_tgz.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
#NO_EXPORT#cat des_tgz.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
diff --git a/etc/etc.i386/EXTRACT_secr.sh b/etc/etc.i386/EXTRACT_secr.sh
index a117c42..718966c 100755
--- a/etc/etc.i386/EXTRACT_secr.sh
+++ b/etc/etc.i386/EXTRACT_secr.sh
@@ -10,5 +10,5 @@ fi
cd $SOURCEDIR
-cat des_tgz.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat libcrypt.aa | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
+cat des_tgz.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat libcrypt.aa | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
diff --git a/etc/etc.i386/EXTRACT_src.sh b/etc/etc.i386/EXTRACT_src.sh
index b6c1d09..0b7c465 100755
--- a/etc/etc.i386/EXTRACT_src.sh
+++ b/etc/etc.i386/EXTRACT_src.sh
@@ -20,22 +20,22 @@ cd $SOURCEDIR
# Note that base.aa is REQUIRED to be able to use the source tree for
# building in.
#
-cat base.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
+cat base.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
#
# The following are optional
#
-cat bin.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat contrib.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat etc.aa | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat games.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat gnu.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat include.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat lib.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-#NO_EXPORT#cat libcrypt.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat libexec.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat sbin.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat share.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat sys.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat usrbin.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
-cat usrsbin.* | gunzip | tar --directory ${EXTRACT_TARGET} -xpf -
+cat bin.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat contrib.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat etc.aa | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat games.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat gnu.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat include.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat lib.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+#NO_EXPORT#cat libcrypt.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat libexec.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat sbin.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat share.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat sys.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat usrbin.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
+cat usrsbin.* | gunzip | tar --unlink --directory ${EXTRACT_TARGET} -xpf -
OpenPOWER on IntegriCloud